@@ -6,6 +6,16 @@ use strict;
 use App::Ack ();
 
 
+=head1 NAME
+
+App::Ack::ConfigDefault
+
+=head1 DESCRIPTION
+
+A module that contains the default configuration for ack.
+
+=cut
+
 sub options {
     return split( /\n/, _options_block() );
 }
@@ -272,7 +282,7 @@ sub _options_block {
 --type-add=haskell:ext:hs,lhs
 
 # HTML
---type-add=html:ext:htm,html
+--type-add=html:ext:htm,html,xhtml
 
 # Jade
 # http://jade-lang.com/
@@ -421,7 +431,7 @@ sub _options_block {
 
 # XML
 # http://www.w3.org/TR/REC-xml/
---type-add=xml:ext:xml,dtd,xsd,xsl,xslt,ent
+--type-add=xml:ext:xml,dtd,xsd,xsl,xslt,ent,wsdl
 --type-add=xml:firstlinematch:/<[?]xml/
 
 # YAML
